@@ -61,19 +61,17 @@ listed in the file CREDITS.
 #include "rvm_query.h"
 #endif /* VERSION_TEST */
 
-#ifndef RVM_USELWP
+#ifdef RVM_USELWP
+#include "rvm_lwp.h"
+#elif defined(RVM_USEPT)
+#include "rvm_pthread.h"
+#else /* fake cthreads wrapper */
 /* XXX bogus by Eric and Peter to get compile */
 #include <cthreads.h>
-
 /* define types symbolically to permit use of non-Cthread thread support */
 #define RVM_MUTEX       struct mutex
-#define RVM_MUTEX_T	mutex_t
 #define RVM_CONDITION	struct condition
-#define RVM_CONDITION_T	condition_t
-
-#else /* RVM_USELWP */ /* special thread support for Coda */
-#include "rvm_lwp.h"
-#endif /* RVM_USELWP */
+#endif
 
 extern rvm_region_def_t *RegionDefs;    /* hooks to rds */
 extern long NRegionDefs;
@@ -887,11 +885,7 @@ rvm_bool_t chk_vm()
 #endif /* VERSION_TEST */
 
     /* open segment file read-only */
-#ifdef DJGPP
     if ((seg_file = fopen(DataFileName,"rb")) == NULL)
-#else
-    if ((seg_file = fopen(DataFileName,"r")) == NULL)
-#endif
         {
         printf("\n? Error opening segment file\n");
         printf("    errno = %d\n",errno);
